@@ -92,8 +92,13 @@ def get_packages(module_prefix: str = None) -> List[Tuple[str, ModuleType]]:
             )
         )
 
+        module_name = None
+
         for path in emtry_module_paths:
 
+            if module_name is not None:
+                break
+
             try:
                 with open(os.path.join(path, "RECORD"), "r") as f:
                     for line in f.readlines():
@@ -101,15 +106,9 @@ def get_packages(module_prefix: str = None) -> List[Tuple[str, ModuleType]]:
                             module_name = line.split("/")[0]
                             break
 
-            except FileNotFoundError as e:
+            except FileNotFoundError:
                 ...
 
-        else:
-            print(f"Can't loat module: {installed_name}")
-
-        # Checks if version is in name:
-        # if package_version in module_name:
-        #     module_name = module_name.replace(f"-{package_version}", "")
 
         if not module_name:
             continue
